<?php

namespace IQBall\App\Controller;

use IQBall\App\Session\MutableSessionHandle;
use IQBall\App\Session\SessionHandle;
use IQBall\App\ViewHttpResponse;
use IQBall\Core\Http\HttpRequest;
use IQBall\Core\Http\HttpResponse;
use IQBall\Core\Model\PersonalSpaceModel;
use IQBall\Core\Model\TacticModel;
use IQBall\Core\Model\TeamModel;
use IQBall\Core\Validation\DefaultValidators;

class UserController {
    private TacticModel $tactics;
    private ?TeamModel $teams;
    private PersonalSpaceModel $personalSpace;

    /**
     * @param TacticModel $tactics
     * @param TeamModel|null $teams
     * @param PersonalSpaceModel $personalSpace
     */
    public function __construct(TacticModel $tactics, ?TeamModel $teams, PersonalSpaceModel $personalSpace) {
        $this->tactics = $tactics;
        $this->teams = $teams;
        $this->personalSpace = $personalSpace;
    }

    /**
     * @param SessionHandle $session
     * @return ViewHttpResponse the home page view
     */
    public function home(SessionHandle $session): ViewHttpResponse {
        $rootFolder = 0;
        $limitNbTactics = 5;

        $user = $session->getAccount()->getUser();

        $lastTactics = $this->tactics->getLast($limitNbTactics, $user->getId());
        $rootTactics = $this->tactics->getFoldefrTactic($user->getId());
        $name = $user->getName();

        if ($this->teams != null) {
            $teams = $this->teams->getAll($user->getId());
        } else {
            $teams = [];
        }

        return ViewHttpResponse::react("views/Home.tsx", [
            "lastTactics" => $lastTactics,
            "allTactics" => $rootTactics,
            "teams" => $teams,
            "username" => $name,
            "currentFolder" => $rootFolder
        ]);
    }

    /**
     * @return ViewHttpResponse account settings page
     */
    public function settings(SessionHandle $session): ViewHttpResponse {
        return ViewHttpResponse::react("views/Settings.tsx", []);
    }

    public function disconnect(MutableSessionHandle $session): HttpResponse {
        $session->destroy();
        return HttpResponse::redirect("/");
    }

    public function createFolder(SessionHandle $session,array $request,int $idParentFolder): HttpResponse{
        $this->personalSpace->createFolder($request['folderName'],$session->getAccount()->getUser()->getId(),$idParentFolder);
        return HttpResponse::redirect("/");
    }



}
